import { ConvertableToDate, LimestoneApiConfig, PriceData } from "./types";
declare type QueryParams = {
    symbols: string[];
    startDate?: ConvertableToDate;
    endDate?: ConvertableToDate;
    date?: ConvertableToDate;
    interval?: number;
    latest?: boolean;
};
export declare class LimestoneQuery {
    protected params: QueryParams;
    constructor(params?: {});
    /**
     * Sets a token symbol to fetch
     * @param symbol - Token symbol string
     * @returns query object
     */
    symbol(symbol: string): LimestoneQueryForSingleSymbol;
    /**
     * Sets token symbols to fetch
     * @param symbols - Array of strings (token symbols)
     * @returns query object
     */
    symbols(symbols: string[]): LimestoneQueryForSeveralSymbols;
    /**
     * Configures query to fetch prices for all supported tokens.
     * It doesn't support any params
     * @returns query object
     */
    allSymbols(): LimestoneQueryForSeveralSymbols;
}
export declare class LimestoneQueryForSingleOrSeveralSymbols<QueryResultType> {
    protected params: QueryParams;
    constructor(params: QueryParams);
    protected getExecutableQuery<T>(update: any): LimestoneQueryExecutable<T>;
    /**
     * Configures query to fetch the latest price/prices
     * It doesn't support any params
     * @returns query object
     */
    latest(): LimestoneQueryExecutable<QueryResultType>;
    /**
     * Configures query to fetch the price for X hours ago.
     * @param hoursCount - Number of hours ago
     * @returns query object
     */
    hoursAgo(hoursCount: number): LimestoneQueryExecutable<QueryResultType>;
    /**
     * Configures query to fetch the price for a specific date.
     * @param date - Date for the historical price (date | timestamp | string)
     * @returns query object
     */
    atDate(date: ConvertableToDate): LimestoneQueryExecutable<QueryResultType>;
}
export declare class LimestoneQueryForSingleSymbol extends LimestoneQueryForSingleOrSeveralSymbols<PriceData> {
    constructor(params: QueryParams);
    /**
     * Configures query to fetch the price in a time range. It is important to use fromDate with toDate query methods
     * @param date - Start date/time for the time range
     *
     * @returns query object
     */
    fromDate(date: ConvertableToDate): LimestoneQueryForSingleSymbol;
    /**
     * Configures query to fetch the price in a time range. toDate method should go after the fromDate
     * @param date - End date/time for the time range
     *
     * @returns query object
     */
    toDate(date: ConvertableToDate): LimestoneQueryExecutable<PriceData[]>;
    /**
     * Configures query to fetch the price for the last few hours
     * @param hoursCount - Number of hours in the time range
     *
     * @returns query object
     */
    forLastHours(hoursCount: number): LimestoneQueryExecutable<PriceData[]>;
    /**
     * Configures query to fetch the price for the last few days
     * @param daysCount - Number of days in the time range
     *
     * @returns query object
     */
    forLastDays(daysCount: number): LimestoneQueryExecutable<PriceData[]>;
}
export declare class LimestoneQueryForSeveralSymbols extends LimestoneQueryForSingleOrSeveralSymbols<{
    [symbol: string]: PriceData;
}> {
    constructor(params: QueryParams);
}
export declare class LimestoneQueryExecutable<QueryResultType> {
    private params;
    constructor(params?: {});
    /**
     * Executes the query
     *
     * @returns Promise resolving the query result (result type depends on the query)
     */
    exec(limestoneApiConfig?: LimestoneApiConfig): Promise<QueryResultType>;
}
/**
 * Initializes and returns an empty query.
 * It doesn't support any params
 * @returns query object
 */
declare const query: () => LimestoneQuery;
export default query;
